Documentation
¶
Index ¶
Constants ¶
const EnvActiveBenchMux = "BENCHMUX_ACTIVE"
EnvActiveBenchMux is the environment variable that controls the active benchmark.
Variables ¶
var ( // DefaultTimeout is the default timeout duration for testing. // It matches the default value of the -test.timeout flag. // See: https://pkg.go.dev/cmd/go#hdr-Testing_flags DefaultTimeout = env.Duration("XTESTING_DEFAULT_TIMEOUT", 10*time.Minute) )
Functions ¶
func CanceledContext ¶
CanceledContext returns a context that is already canceled. It is useful for testing functions that return a context and expect it to be canceled.
Types ¶
type BenchMux ¶
type BenchMux struct {
// contains filtered or unexported fields
}
BenchMux is a benchmark multiplexer that executes a benchmark based on the value set in the EnvActiveBenchMux environment variable.
Click to show internal directories.
Click to hide internal directories.